@@ -13,7 +13,6 @@
 //*****************************************************************************
 
 #include "kernel/mod2.h"
-#ifdef HAVE_PYTHON
 
 #include "omalloc/omalloc.h"
 #include "misc/intvec.h"
@@ -29,6 +28,7 @@
 
 #include "Singular/mod_lib.h"
 
+#ifdef HAVE_PYTHON
 #include <Python.h>
 
 // #include <iterator>             // std::distance
@@ -64,7 +64,7 @@ private:
   /// safely takes care of destruction on program termination
   static PythonInterpreter& instance()
   {
-    static PythonInterpreter init_interpreter;
+    STATIC_INST_VAR PythonInterpreter init_interpreter;
     return init_interpreter;
   }
 
@@ -740,5 +740,11 @@ extern "C" int SI_MOD_INIT(pyobject)(SModulFunctions* psModulFunctions)
   return MAX_TOK;
 }
 #undef PYOBJECT_ADD_C_PROC
+#else
+extern "C" int SI_MOD_INIT(pyobject)(SModulFunctions* psModulFunctions)
+{
+  PrintS("no pyobject support\n");
+  return MAX_TOK;
+}
 
 #endif /* HAVE_PYTHON */
