@@ -22,6 +22,7 @@
 
 #include "config.h"
 
+#include <math.h>
 
 #include "canonicalform.h"
 #include "facMul.h"
@@ -37,6 +38,10 @@
 
 #ifdef HAVE_FLINT
 #include "FLINTconvert.h"
+#include "flint/fq_nmod_vec.h"
+#if __FLINT_RELEASE >= 20503
+#include "flint/fmpz_mod.h"
+#endif
 #endif
 
 // univariate polys
