@@ -11,14 +11,15 @@
 #include "cf_defs.h"
 #include "ffops.h"
 
-int ff_prime = 0;
-int ff_halfprime = 0;
-bool ff_big = false;
-short * ff_invtab = new short [32767];
+VAR int ff_prime = 0;
+VAR int ff_halfprime = 0;
+VAR bool ff_big = false;
+VAR short * ff_invtab = new short [32767];
 
 void ff_setprime ( const int p )
 {
-    if ( p != ff_prime ) {
+    if ( p != ff_prime )
+    {
         ff_prime = p;
         ff_halfprime = ff_prime / 2;
         if ( ! ff_big )
