@@ -41,6 +41,7 @@ VAR int create_count = 0;
  *         2: cannot change tailRing: strat==NULL
  *
  ***************************************************************/
+#ifdef STDZ_EXCHANGE_DURING_REDUCTION
 int ksReducePolyZ(LObject* PR,
                  TObject* PW,
                  poly spNoether,
@@ -86,7 +87,7 @@ int ksReducePolyZ(LObject* PR,
     // for the time being: we know currRing==strat->tailRing
     // no exp-bound checking needed
     // (only needed if exp-bound(tailring)<exp-b(currRing))
-    if (PR->bucket!=NULL)  nc_kBucketPolyRed_Z(PR->bucket, p2,coef);
+    if (PR->bucket!=NULL)  nc_kBucketPolyRed_Z(PR->bucket, p2,coef,FALSE);// TODO:reduce
     else
     {
       poly _p = (PR->t_p != NULL ? PR->t_p : PR->p);
@@ -149,7 +150,7 @@ int ksReducePolyZ(LObject* PR,
   }
 #endif
 
-  // take care of coef buisness
+  // take care of coef business
   if (! n_IsOne(pGetCoeff(p2), tailRing->cf))
   {
     number bn = pGetCoeff(lm);
@@ -183,13 +184,15 @@ int ksReducePolyZ(LObject* PR,
 
   return ret;
 }
+#endif
 
 int ksReducePoly(LObject* PR,
                  TObject* PW,
                  poly spNoether,
                  number *coef,
                  poly *mon,
-                 kStrategy strat)
+                 kStrategy strat,
+                 BOOLEAN reduce)
 {
 #ifdef KDEBUG
   red_count++;
@@ -231,7 +234,7 @@ int ksReducePoly(LObject* PR,
     // for the time being: we know currRing==strat->tailRing
     // no exp-bound checking needed
     // (only needed if exp-bound(tailring)<exp-b(currRing))
-    if (PR->bucket!=NULL)  nc_kBucketPolyRed_Z(PR->bucket, p2,coef);
+    if (PR->bucket!=NULL)  nc_kBucketPolyRed_Z(PR->bucket, p2,coef,reduce);
     else
     {
       poly _p = (PR->t_p != NULL ? PR->t_p : PR->p);
@@ -253,7 +256,7 @@ int ksReducePoly(LObject* PR,
 
   p_ExpVectorSub(lm, p2, tailRing); // Calculate the Monomial we must multiply to p2
 
-  //if (tailRing != currRing)
+  if (tailRing != currRing)
   {
     // check that reduction does not violate exp bound
     while (PW->max_exp != NULL && !p_LmExpVectorAddIsOk(lm, PW->max_exp, tailRing))
@@ -282,12 +285,30 @@ int ksReducePoly(LObject* PR,
   }
 #endif
 
-  // take care of coef buisness
+  // take care of coef business
   if (! n_IsOne(pGetCoeff(p2), tailRing->cf))
   {
     number bn = pGetCoeff(lm);
     number an = pGetCoeff(p2);
     int ct = ksCheckCoeff(&an, &bn, tailRing->cf);    // Calculate special LC
+    if (reduce)
+    {
+      if(n_IsMOne(an, tailRing->cf))
+      {
+        an=n_InpNeg(an, tailRing->cf);
+        bn=n_InpNeg(bn, tailRing->cf);
+        ct+=1;
+      }
+#ifdef KDEBUG
+      else if(!n_IsOne(an,tailRing->cf))
+      {
+        StringSetS("ksReducePoly: ");n_Write(an,tailRing->cf);
+        StringAppendS("\n");
+        PrintS(StringEndS());
+      }
+#endif
+    }
+    // in case of reduce, do not multiply PR
     p_SetCoeff(lm, bn, tailRing);
     if ((ct == 0) || (ct == 2))
       PR->Tail_Mult_nn(an);
@@ -322,6 +343,7 @@ int ksReducePoly(LObject* PR,
 }
 
 #ifdef HAVE_RINGS
+#ifdef STDZ_EXCHANGE_DURING_REDUCTION
 int ksReducePolyGCD(LObject* PR,
                  TObject* PW,
                  poly spNoether,
@@ -368,7 +390,7 @@ int ksReducePolyGCD(LObject* PR,
     // for the time being: we know currRing==strat->tailRing
     // no exp-bound checking needed
     // (only needed if exp-bound(tailring)<exp-b(currRing))
-    if (PR->bucket!=NULL)  nc_kBucketPolyRed_Z(PR->bucket, p2,coef);
+    if (PR->bucket!=NULL)  nc_kBucketPolyRed_Z(PR->bucket, p2,coef,TRUE);
     else
     {
       poly _p = (PR->t_p != NULL ? PR->t_p : PR->p);
@@ -407,7 +429,7 @@ int ksReducePolyGCD(LObject* PR,
 #endif
 
   number ct, an, bn;
-  // take care of coef buisness
+  // take care of coef business
   if (! n_IsOne(pGetCoeff(p2), tailRing->cf))
   {
     ct = n_ExtGcd(pGetCoeff(p1), pGetCoeff(p2), &an, &bn, tailRing->cf);    // Calculate GCD
@@ -447,6 +469,7 @@ int ksReducePolyGCD(LObject* PR,
   return ret;
 }
 #endif
+#endif
 
 /* Computes a reduction of the lead coefficient only. We have already tested
  * that lm(PW) divides lm(PR), but lc(PW) does not divide lc(PR). We have
@@ -503,7 +526,7 @@ int ksReducePolyLC(LObject* PR,
     // for the time being: we know currRing==strat->tailRing
     // no exp-bound checking needed
     // (only needed if exp-bound(tailring)<exp-b(currRing))
-    if (PR->bucket!=NULL)  nc_kBucketPolyRed_Z(PR->bucket, p2,coef);
+    if (PR->bucket!=NULL)  nc_kBucketPolyRed_Z(PR->bucket, p2,coef,FALSE);
     else
     {
       poly _p = (PR->t_p != NULL ? PR->t_p : PR->p);
@@ -616,7 +639,7 @@ int ksReducePolyBound(LObject* PR,
     // for the time being: we know currRing==strat->tailRing
     // no exp-bound checking needed
     // (only needed if exp-bound(tailring)<exp-b(currRing))
-    if (PR->bucket!=NULL)  nc_kBucketPolyRed_Z(PR->bucket, p2,coef);
+    if (PR->bucket!=NULL)  nc_kBucketPolyRed_Z(PR->bucket, p2,coef,FALSE);
     else
     {
       poly _p = (PR->t_p != NULL ? PR->t_p : PR->p);
@@ -667,7 +690,7 @@ int ksReducePolyBound(LObject* PR,
   }
 #endif
 
-  // take care of coef buisness
+  // take care of coef business
   if (! n_IsOne(pGetCoeff(p2), tailRing->cf))
   {
     number bn = pGetCoeff(lm);
@@ -830,7 +853,7 @@ int ksReducePolySig(LObject* PR,
     // for the time being: we know currRing==strat->tailRing
     // no exp-bound checking needed
     // (only needed if exp-bound(tailring)<exp-b(currRing))
-    if (PR->bucket!=NULL)  nc_kBucketPolyRed_Z(PR->bucket, p2,coef);
+    if (PR->bucket!=NULL)  nc_kBucketPolyRed_Z(PR->bucket, p2,coef,FALSE);
     else
     {
       poly _p = (PR->t_p != NULL ? PR->t_p : PR->p);
@@ -881,7 +904,7 @@ int ksReducePolySig(LObject* PR,
   }
 #endif
 
-  // take care of coef buisness
+  // take care of coef business
   if (! n_IsOne(pGetCoeff(p2), tailRing->cf))
   {
     number bn = pGetCoeff(lm);
@@ -987,7 +1010,7 @@ int ksReducePolySigRing(LObject* PR,
     printf("--------------\n");
 #endif
     p_ExpVectorAddSub(sigMult,PR->GetLmCurrRing(),PW->GetLmCurrRing(),currRing);
-    //I have also to set the leading coeficient for sigMult (in the case of rings)
+    //I have also to set the leading coefficient for sigMult (in the case of rings)
     if(rField_is_Ring(currRing))
     {
       pSetCoeff(sigMult,nMult(nDiv(pGetCoeff(PR->p),pGetCoeff(PW->p)), pGetCoeff(sigMult)));
@@ -1021,7 +1044,7 @@ int ksReducePolySigRing(LObject* PR,
       poly origsig = pCopy(PR->sig);
       if(sigMult != NULL)
         PR->sig = pHead(pSub(PR->sig, sigMult));
-      //The sigs have the same lm, have to substract
+      //The sigs have the same lm, have to subtract
       //It may happen that now the signature is 0 (drop)
       if(PR->sig == NULL)
       {
@@ -1077,7 +1100,7 @@ int ksReducePolySigRing(LObject* PR,
     // for the time being: we know currRing==strat->tailRing
     // no exp-bound checking needed
     // (only needed if exp-bound(tailring)<exp-b(currRing))
-    if (PR->bucket!=NULL)  nc_kBucketPolyRed_Z(PR->bucket, p2,coef);
+    if (PR->bucket!=NULL)  nc_kBucketPolyRed_Z(PR->bucket, p2,coef,FALSE);
     else
     {
       poly _p = (PR->t_p != NULL ? PR->t_p : PR->p);
@@ -1128,7 +1151,7 @@ int ksReducePolySigRing(LObject* PR,
   }
 #endif
 
-  // take care of coef buisness
+  // take care of coef business
   if(rField_is_Ring(currRing))
   {
     p_SetCoeff(lm, nDiv(pGetCoeff(lm),pGetCoeff(p2)), tailRing);
@@ -1413,7 +1436,7 @@ int ksReducePolyTailBound(LObject* PR, TObject* PW, int bound, poly Current, pol
 
 /***************************************************************
  *
- * Auxillary Routines
+ * Auxiliary Routines
  *
  *
  ***************************************************************/
