@@ -594,6 +594,7 @@ resolvente syResolvente(ideal arg, int maxlength, int * length,
     if ((res[i]!=NULL) && ! idIs0(res[i]))
     {
       id_Shift(res[i],-rGetMaxSyzComp(i, currRing),currRing);
+      res[i]->rank=idElem(res[i-1]);
     }
   }
 /*--- going back to the original ring -------------------------*/
@@ -1160,3 +1161,52 @@ intvec * syNewBetti(resolvente res, intvec ** weights, int length)
 }
 #endif
 
+syStrategy syMres_with_map(ideal arg, int maxlength,intvec * w, ideal &trans)
+{
+  syStrategy res=syResolution(arg,maxlength,w,1);
+  ideal *r=res->minres;
+  if (r==NULL) r=res->fullres;
+  trans=idLift(arg,r[0],NULL,TRUE,FALSE,FALSE,NULL);
+  return res;
+}
+
+void syMinimize_with_map(syStrategy res, ideal &trans)
+{
+  ideal *r=res->minres;
+  if (r==NULL) r=res->fullres;
+  ideal org=idCopy(r[0]);
+  res=syMinimize(res);
+  r=res->minres;
+  if (r==NULL) r=res->fullres;
+  trans=idLift(org,r[0],NULL,TRUE,FALSE,FALSE,NULL);
+}
+
+syStrategy syMinimizeCopy(syStrategy org)
+{
+  syStrategy result=(syStrategy)omAlloc0(sizeof(ssyStrategy));
+
+  result->length=org->length;
+  if (org->weights!=NULL)
+  {
+    result->weights=(intvec**)omAlloc0(org->length*sizeof(intvec*));
+    for (int i=org->length-1;i>=0;i--)
+    {
+      if (org->weights[i]!=NULL)
+      {
+        result->weights[i]=ivCopy(org->weights[i]);
+      }
+    }
+  }
+  result->fullres = (resolvente)omAlloc0((result->length+1)*sizeof(ideal));
+  resolvente fr = org->minres;
+  if (fr==NULL) fr=org->fullres;
+
+  for (int i=result->length-1;i>=0;i--)
+  {
+    if (fr[i]!=NULL)
+      result->fullres[i] = idCopy(fr[i]);
+  }
+  result->list_length=result->length;
+  result=syMinimize(result);
+  return result;
+}
