@@ -48,7 +48,7 @@
 /*2
 *returns a minimized set of generators of h1
 */
-ideal idMinBase (ideal h1)
+ideal idMinBase (ideal h1, ideal *SB)
 {
   ideal h2, h3,h4,e;
   int j,k;
@@ -82,9 +82,8 @@ ideal idMinBase (ideal h1)
   {
     return e;
   }
-  pEnlargeSet(&(e->m),IDELEMS(e),15);
-  IDELEMS(e) = 16;
   h2 = kStd(h1,currRing->qideal,isNotHomog,NULL);
+  if (SB!=NULL) *SB=h2;
   h3 = idMaxIdeal(1);
   h4=idMult(h2,h3);
   idDelete(&h3);
@@ -114,7 +113,7 @@ ideal idMinBase (ideal h1)
       }
     }
   }
-  idDelete(&h2);
+  if (SB==NULL) idDelete(&h2);
   idDelete(&h3);
   idDelete(&h4);
   if (currRing->qideal!=NULL)
@@ -603,6 +602,7 @@ ideal idMultSect(resolvente arg, int length, GbVariant alg)
  * where G: GB of (h1+h11)
  *       T: G/h11=h1*T
  *       S: relative syzygies(h1) modulo h11
+ * if V_IDLIFT is set, ignore/do not return S
  */
 static ideal idPrepare (ideal  h1, ideal h11, tHomog hom, int syzcomp, intvec **w, GbVariant alg)
 {
@@ -610,7 +610,7 @@ static ideal idPrepare (ideal  h1, ideal h11, tHomog hom, int syzcomp, intvec **
   int     j,k;
   poly    p,q;
 
-  if (idIs0(h1)) return NULL;
+  assume(!idIs0(h1));
   k = id_RankFreeModule(h1,currRing);
   if (h11!=NULL)
   {
@@ -1161,8 +1161,18 @@ ideal idLift(ideal mod, ideal submod,ideal *rest, BOOLEAN goodShape,
     s_mod = mod;
     s_temp = idCopy(submod);
   }
+  BITSET save2;
+  SI_SAVE_OPT2(save2);
+
+  if ((rest==NULL)
+  && (!rField_is_Ring(currRing))
+  && (!rIsNCRing(currRing))
+  && (!TEST_OPT_RETURN_SB))
+    si_opt_2 |=Sy_bit(V_IDLIFT);
+  else
+    si_opt_2 &=~Sy_bit(V_IDLIFT);
   ideal s_h3;
-  if (isSB)
+  if (isSB && !TEST_OPT_IDLIFT)
   {
     s_h3 = idCopy(s_mod);
     idPrepareStd(s_h3, k+comps_to_add);
@@ -1171,6 +1181,8 @@ ideal idLift(ideal mod, ideal submod,ideal *rest, BOOLEAN goodShape,
   {
     s_h3 = idPrepare(s_mod,NULL,(tHomog)FALSE,k+comps_to_add,NULL,alg);
   }
+  SI_RESTORE_OPT2(save2);
+
   if (!goodShape)
   {
     for (j=0;j<IDELEMS(s_h3);j++)
@@ -1803,11 +1815,7 @@ ideal idElimination (ideal h1,poly delVar,intvec *hilb, GbVariant alg)
     WarnS("wrong algorithm for GB");
     alg=GbDefault;
   }
-  BITSET save2;
-  SI_SAVE_OPT2(save2);
-  if (!TEST_OPT_RETURN_SB) si_opt_2|=V_IDELIM;
   hh=idGroebner(h,0,alg,hilb);
-  SI_RESTORE_OPT2(save2);
   // go back to the original ring
   rChangeCurrRing(origR);
   i = IDELEMS(hh)-1;
@@ -3006,7 +3014,7 @@ static BOOLEAN id_sat_vars_sp(kStrategy strat)
     int *m0=(int*)omAlloc0((1+rVar(currRing))*sizeof(int));
     p_GetExpV(p,mm,currRing);
     bool nonTrivialSaturationToBeDone=true;
-    for (p=pNext(p); p!=NULL; pIter(p))
+    for (; p!=NULL; pIter(p))
     {
       nonTrivialSaturationToBeDone=false;
       p_GetExpV(p,m0,currRing);
@@ -3031,9 +3039,9 @@ static BOOLEAN id_sat_vars_sp(kStrategy strat)
       //  for (int i=rVar(currRing); i>0; i--)
       //    if (mm[i]!=0) Print("x_%d:%d ",i,mm[i]);
       //PrintLn();
-      strat->P.Init(currRing);
+      strat->P.Init(strat->tailRing);
       //memset(&strat->P,0,sizeof(strat->P));
-      strat->P.tailRing = strat->tailRing;
+      //strat->P.tailRing = strat->tailRing; // done by Init
       strat->P.p=p;
       while(p!=NULL)
       {
@@ -3059,7 +3067,7 @@ static BOOLEAN id_sat_vars_sp(kStrategy strat)
     int *m0=(int*)omAlloc0((1+rVar(currRing))*sizeof(int));
     p_GetExpV(p,mm,strat->tailRing);
     bool nonTrivialSaturationToBeDone=true;
-    for (p = pNext(p); p!=NULL; pIter(p))
+    for (; p!=NULL; pIter(p))
     {
       nonTrivialSaturationToBeDone=false;
       p_GetExpV(p,m0,strat->tailRing);
@@ -3083,9 +3091,9 @@ static BOOLEAN id_sat_vars_sp(kStrategy strat)
       //  for (int i=rVar(currRing); i>0; i--)
       //    if (mm[i]!=0) Print("x_%d:%d ",i,mm[i]);
       //PrintLn();
-      strat->P.Init(currRing);
+      strat->P.Init(strat->tailRing);
       //memset(&strat->P,0,sizeof(strat->P));
-      strat->P.tailRing = strat->tailRing;
+      //strat->P.tailRing = strat->tailRing;// done by Init
       strat->P.t_p=p;
       while(p!=NULL)
       {
@@ -3131,6 +3139,12 @@ ideal id_Satstd(const ideal I, ideal J, const ring r)
   else
   {
     poly x = J->m[0];
+    if (pNext(x)!=NULL)
+    {
+      Werror("generator must be a monomial");
+      if (currRing!=save) rChangeCurrRing(save);
+      return NULL;
+    }
     for (int i=1; i<=r->N; i++)
     {
       int li = p_GetExp(x,i,r);
@@ -3151,6 +3165,263 @@ ideal id_Satstd(const ideal I, ideal J, const ring r)
   return res;
 }
 
+ideal id_Sat_principal(ideal I, ideal J, const ring origR)
+{
+  rRingOrder_t    *ord;
+  int    *block0,*block1;
+  int    **wv;
+
+  // construction extension ring
+  ord=(rRingOrder_t*)omAlloc0(4*sizeof(rRingOrder_t));
+  block0=(int*)omAlloc0(4*sizeof(int));
+  block1=(int*)omAlloc0(4*sizeof(int));
+  wv=(int**) omAlloc0(4*sizeof(int**));
+  wv[0]=(int*)omAlloc0((rVar(origR) + 2)*sizeof(int));
+  block0[0] = block0[1] = 1;
+  block1[0] = block1[1] = rVar(origR)+1;
+  // use this special ordering: like ringorder_a, except that pFDeg, pWeights
+  // ignore it
+  ord[0] = ringorder_aa;
+  wv[0][rVar(origR)]=1;
+  BOOLEAN wp=FALSE;
+  for (int j=0;j<rVar(origR);j++)
+    if (p_Weight(j+1,origR)!=1) { wp=TRUE;break; }
+  if (wp)
+  {
+    wv[1]=(int*)omAlloc0((rVar(origR) + 1)*sizeof(int));
+    for (int j=0;j<rVar(origR);j++)
+      wv[1][j]=p_Weight(j+1,origR);
+    ord[1] = ringorder_wp;
+  }
+  else
+    ord[1] = ringorder_dp;
+  ord[2] = ringorder_C;
+  ord[3] = (rRingOrder_t)0;
+  char **names=(char**)omAlloc0((origR->N+1) * sizeof(char *));
+  for (int j=0;j<rVar(origR);j++)
+    names[j]=origR->names[j];
+  names[rVar(origR)]=(char*)"@";
+  ring tmpR=rDefault(nCopyCoeff(origR->cf),rVar(origR)+1,names,4,ord,block0,block1,wv);
+  omFree(names);
+  rComplete(tmpR, 1);
+  rChangeCurrRing(tmpR);
+  // map I
+  ideal II=idrCopyR(I,origR,tmpR);
+  // map J
+  ideal JJ=idrCopyR(J,origR,tmpR);
+  // J[1]*t-1
+  poly t=pOne();
+  p_SetExp(t,rVar(tmpR),1,tmpR);
+  p_Setm(t,tmpR);
+  poly p=JJ->m[0];
+  p_Norm(p,currRing);
+  p=p_Mult_q(p,t,tmpR);
+  p=p_Sub(p,pOne(),tmpR);
+  JJ->m[0]=p;
+  ideal T=id_SimpleAdd(II,JJ,tmpR);
+  idTest(T);
+  id_Delete(&II,tmpR);
+  id_Delete(&JJ,tmpR);
+  // elimination
+  t=pOne();
+  p_SetExp(t,rVar(tmpR),1,tmpR);
+  p_Setm(t,tmpR);
+  ideal TT=idGroebner(T,0,GbStd);
+  p_Delete(&t,tmpR);
+  for(int j=0;j<IDELEMS(TT);j++)
+  {
+    if ((TT->m[j]!=NULL)
+    && (p_GetExp(TT->m[j],rVar(tmpR),tmpR)>0))
+    {
+      p_Delete(&TT->m[j],tmpR);
+    }
+  }
+  // map back
+  ideal TTT=idrCopyR(TT,tmpR,origR);
+  id_Delete(&TT,tmpR);
+  rChangeCurrRing(origR);
+  rDelete(tmpR);
+  idSkipZeroes(TTT);
+  return TTT;
+}
+
+ideal idSaturate(ideal I, ideal J, int &k, BOOLEAN isIdeal)
+{
+  if(idIs0(I))
+  {
+     I=idCopy(I);
+     idSkipZeroes(I);
+     return(I);
+  }
+  //if (idElem(J)==1)
+  //{
+  //  idSkipZeroes(J);
+  //  return id_Sat_principal(I,J,currRing);
+  //}
+  //---------------------------------------------------
+  BOOLEAN only_vars=TRUE; // enabled for I:x_i
+  if (idElem(J)==1)
+  {
+    for(int j=IDELEMS(J)-1;j>=0;j--)
+    {
+      poly p=J->m[j];
+      if (p!=NULL)
+      {
+        if (pVar(p)==0)
+        {
+          only_vars=FALSE;
+          break;
+        }
+      }
+    }
+  }
+  if (only_vars && isIdeal && rOrd_is_Totaldegree_Ordering(currRing)
+  && (idElem(J)==1))
+  {
+    ideal Iquot,Istd;
+    intvec *w=NULL;
+    Istd=id_Satstd(I,J,currRing);
+    k=0;
+    loop
+    {
+      k++;
+      Iquot=idQuot(Istd,J,TRUE,isIdeal);
+      ideal tmp=kNF(Istd,currRing->qideal,Iquot,5);
+      int  elem=idElem(tmp);
+      id_Delete(&tmp,currRing);
+      id_Delete(&Istd,currRing);
+      Istd=Iquot;
+      w=NULL;
+      Istd=kStd(Iquot,currRing->qideal,testHomog,&w);
+      if (w!=NULL) delete w;
+      id_Delete(&Iquot,currRing);
+      if (elem==0) break;
+    }
+    k--;
+    idSkipZeroes(Istd);
+  //PrintS("\nSatstd:\n");
+  //iiWriteMatrix((matrix)I,"I",1,currRing,0); PrintLn();
+  //iiWriteMatrix((matrix)J,"J",1,currRing,0); PrintLn();
+  //iiWriteMatrix((matrix)Istd,"res",1,currRing,0);PrintLn();
+  //id_Delete(&Istd,currRing);
+    return Istd;
+  }
+  //--------------------------------------------------
+  ideal Iquot,Istd;
+  intvec *w=NULL;
+  Istd=idCopy(I);
+  k=0;
+  loop
+  {
+    k++;
+    Iquot=idQuot(Istd,J,FALSE,isIdeal);
+    ideal tmp=kNF(Istd,currRing->qideal,Iquot,5);
+    int  elem=idElem(tmp);
+    id_Delete(&tmp,currRing);
+    id_Delete(&Istd,currRing);
+    Istd=Iquot;
+    if (elem==0) break;
+  }
+  k--;
+  Istd=kStd(Iquot,currRing->qideal,testHomog,&w);
+  idSkipZeroes(Istd);
+  //if (only_vars)
+  //{
+  //  iiWriteMatrix((matrix)Istd,"org",1,currRing,0);
+  //}
+  return Istd;
+}
+
+ideal id_Homogenize(ideal I, int var_num, const ring r)
+{
+  ideal II=id_Copy(I,r);
+  if (var_num=1)
+  {
+    ring tmpR=rAssure_Dp_C(r);
+    if (tmpR!=r)
+    {
+      rChangeCurrRing(tmpR);
+      II=idrMoveR(II,r,tmpR);
+    }
+    ideal III=id_Homogen(II,1,tmpR);
+    id_Delete(&II,tmpR);
+    intvec *ww=NULL;
+    II=kStd(III,currRing->qideal,(tHomog)TRUE,&ww);
+    if (ww!=NULL) delete ww;
+    id_Delete(&III,tmpR);
+    if (tmpR!=r)
+    {
+      rChangeCurrRing(r);
+      II=idrMoveR(II,tmpR,r);
+    }
+    return II;
+  }
+  ideal III=idInit(IDELEMS(II),1);
+  int *perm=(int*)omAlloc0((rVar(r)+1)*sizeof(int));
+  for(int i=rVar(r)-1; i>0; i--) perm[i]=i;
+  perm[var_num]=1;
+  perm[1]=var_num;
+  for(int i=IDELEMS(II)-1; i>=0;i--)
+  {
+    III->m[i]=p_PermPoly(II->m[i],perm,r,r,ndCopyMap,NULL,0,FALSE);
+  }
+  id_Delete(&II,r);
+  II=id_Homogenize(III,1,r);
+  id_Delete(&III,r);
+  III=idInit(IDELEMS(II),1);
+  for(int i=IDELEMS(II)-1; i>=0;i--)
+  {
+    III->m[i]=p_PermPoly(II->m[i],perm,r,r,ndCopyMap,NULL,0,FALSE);
+  }
+  id_Delete(&II,r);
+  return III;
+}
+
+ideal id_HomogenizeW(ideal I, int var_num, intvec *w,const ring r)
+{
+  ideal II=id_Copy(I,r);
+  if (var_num=1)
+  {
+    ring tmpR=rAssure_Wp_C(r,w);
+    if (tmpR!=r)
+    {
+      rChangeCurrRing(tmpR);
+      II=idrMoveR(II,r,tmpR);
+    }
+    ideal III=id_Homogen(II,1,tmpR);
+    id_Delete(&II,tmpR);
+    intvec *ww=NULL;
+    II=kStd(III,currRing->qideal,(tHomog)TRUE,&ww);
+    if (ww!=NULL) delete ww;
+    id_Delete(&III,tmpR);
+    if (tmpR!=r)
+    {
+      rChangeCurrRing(r);
+      II=idrMoveR(II,tmpR,r);
+    }
+    return II;
+  }
+  ideal III=idInit(IDELEMS(II),1);
+  int *perm=(int*)omAlloc0((rVar(r)+1)*sizeof(int));
+  for(int i=rVar(r)-1; i>0; i--) perm[i]=i;
+  perm[var_num]=1;
+  perm[1]=var_num;
+  for(int i=IDELEMS(II)-1; i>=0;i--)
+  {
+    III->m[i]=p_PermPoly(II->m[i],perm,r,r,ndCopyMap,NULL,0,FALSE);
+  }
+  id_Delete(&II,r);
+  II=id_HomogenizeW(III,1,w,r);
+  id_Delete(&III,r);
+  III=idInit(IDELEMS(II),1);
+  for(int i=IDELEMS(II)-1; i>=0;i--)
+  {
+    III->m[i]=p_PermPoly(II->m[i],perm,r,r,ndCopyMap,NULL,0,FALSE);
+  }
+  id_Delete(&II,r);
+  return III;
+}
+
 GbVariant syGetAlgorithm(char *n, const ring r, const ideal /*M*/)
 {
   GbVariant alg=GbDefault;
