@@ -100,7 +100,7 @@ static inline BOOLEAN idHomModule(ideal m, ideal Q,intvec **w)
 
 BOOLEAN idTestHomModule(ideal m, ideal Q, intvec *w);
 
-ideal idMinBase (ideal h1);
+ideal idMinBase (ideal h1, ideal *SB=NULL);
   /*returns a minimized set of generators of h1*/
 void    idInitChoise (int r,int beg,int end,BOOLEAN *endch,int * choise);
 void    idGetNextChoise (int r,int end,BOOLEAN *endch,int * choise);
@@ -129,6 +129,7 @@ enum GbVariant
   GbNfmod,
   GbStdSat,
   GbSingmatic
+  // and test variants
 };
 
 ideal   idSect (ideal h1,ideal h2, GbVariant a=GbDefault);
@@ -159,6 +160,7 @@ poly idMinor(matrix a, int ar, unsigned long which, ideal R = NULL);
 ideal   idMinors(matrix a, int ar, ideal R = NULL);
 
 ideal idMinEmbedding(ideal arg,BOOLEAN inPlace=FALSE, intvec **w=NULL);
+ideal idMinEmbedding_with_map(ideal arg,intvec **w, ideal &trans);
 
 ideal   idHead(ideal h);
 
@@ -199,6 +201,10 @@ ideal id_Farey(ideal x, number N, const ring r);
 ideal id_TensorModuleMult(const int m, const ideal M, const ring rRing); // image of certain map for BGG
 
 ideal id_Satstd(const ideal I, ideal J, const ring r);
+ideal id_Sat_principal(const ideal I, ideal J, const ring r);
+ideal idSaturate(ideal I, ideal J, int &ki, BOOLEAN isIdeal=TRUE);
+ideal id_Homogenize(ideal I, int var_num, const ring r);
+ideal id_HomogenizeW(ideal I, int var_num, intvec *w,const ring r);
 
 GbVariant syGetAlgorithm(char *n, const ring r, const ideal M);
 #endif
