@@ -9,6 +9,7 @@
 #include "misc/auxiliary.h"
 
 #ifdef HAVE_RINGS
+#include "coeffs/coeffs.h"
 
 #if SI_INTEGER_VARIANT == 3
 #define SR_HDL(A) ((long)(A))
@@ -25,6 +26,10 @@
 BOOLEAN nrzInitChar    (coeffs r,  void * parameter);
 
 void    nrzWrite       (number a, const coeffs r); /*for rmodulon.cc*/
+void    nrzDelete      (number *a, const coeffs);  /*for rmodulon.cc*/
+int     nrzSize        (number a, const coeffs);   /*for rmodulon.cc*/
+void nrzWriteFd(number n, const ssiInfo* d, const coeffs); /*for rmodulon.cc*/
+number nrzReadFd(const ssiInfo *d, const coeffs);  /*for rmodulon.cc*/
 
 number  nrzInit        (long i, const coeffs r); /*for SAGE, better: n_Init*/
 
