@@ -276,6 +276,24 @@ intvec * ivAdd(intvec * a, intvec * b)
   return iv;
 }
 
+intvec * ivAddShift(intvec * a, intvec * b, int s)
+{
+  if (a->cols() != b->cols()) return NULL;
+  if (a->cols() == 1)
+  {
+    int i;
+    intvec * iv;
+    int ma = si_max(a->rows(),b->rows()+s);
+    iv=new intvec(ma);
+    for (i=a->rows()-1;i>=0;i--)
+      (*iv)[i] = (*a)[i];
+    for(i=b->rows()+s-1;i>=s;i--)
+      (*iv)[i] += (*b)[i-s];
+    return iv;
+  }
+  return NULL;
+}
+
 intvec * ivSub(intvec * a, intvec * b)
 {
   intvec * iv;
