@@ -742,18 +742,6 @@ void kBucket_Minus_m_Mult_p(kBucket_pt bucket, poly m, poly p, int *l,
   kbTest(bucket);
   i = pLogLength(l1);
 
-#if defined(HAVE_PLURAL)
-  if ((rField_is_Ring(r) && !(rField_is_Domain(r)))
-  ||(rIsPluralRing(r)))
-  {
-    pSetCoeff0(m, n_InpNeg(pGetCoeff(m),r->cf));
-    p1=r->p_Procs->pp_mm_Mult(p,m,r);
-    pSetCoeff0(m, n_InpNeg(pGetCoeff(m),r->cf));
-    l1=pLength(p1);
-    i = pLogLength(l1);
-  }
-  else
-#endif
   {
     if ((i <= bucket->buckets_used) && (bucket->buckets[i] != NULL))
     {
@@ -1080,8 +1068,6 @@ void kBucketTakeOutComp(kBucket_pt bucket,
 // Reduction of Bpoly with a given poly
 //
 
-extern int ksCheckCoeff(number *a, number *b);
-
 number kBucketPolyRed(kBucket_pt bucket,
                       poly p1, int l1,
                       poly spNoether)
@@ -1108,8 +1094,6 @@ number kBucketPolyRed(kBucket_pt bucket,
   if (! n_IsOne(pGetCoeff(p1),r->cf))
   {
     number an = pGetCoeff(p1), bn = pGetCoeff(lm);
-//StringSetS("##### an = "); nWrite(an); PrintS(StringEndS("\n")); // NOTE/TODO: use StringAppendS("\n"); omFree(s);
-//StringSetS("##### bn = "); nWrite(bn); PrintS(StringEndS("\n")); // NOTE/TODO: use StringAppendS("\n"); omFree(s);
     /* ksCheckCoeff: divide out gcd from an and bn: */
     int ct = ksCheckCoeff(&an, &bn,r->cf);
     /* the previous command returns ct=0 or ct=2 iff an!=1
@@ -1119,11 +1103,6 @@ number kBucketPolyRed(kBucket_pt bucket,
     p_SetCoeff(lm, bn, r);
     if ((ct == 0) || (ct == 2))
     {
-      /* next line used to be here before but is WRONG:
-      kBucket_Mult_n(bucket, an);
-        its use would result in a wrong sign for the tail of bucket
-        in the reduction */
-
       /* correct factor for cancelation by changing sign if an=-1 */
       if (rField_is_Ring(r))
         lm = __p_Mult_nn(lm, an, r);
@@ -1206,6 +1185,100 @@ number kBucketPolyRed(kBucket_pt bucket,
   return rn;
 }
 
+void kBucketPolyRedNF(kBucket_pt bucket,
+                      poly p1, int l1,
+                      poly spNoether)
+{
+  ring r=bucket->bucket_ring;
+  assume((!rIsPluralRing(r))||p_LmEqual(p1,kBucketGetLm(bucket), r));
+  assume(p1 != NULL &&
+         p_DivisibleBy(p1,  kBucketGetLm(bucket), r));
+  assume(pLength(p1) == (unsigned) l1);
+
+  poly a1 = pNext(p1), lm = kBucketExtractLm(bucket);
+  BOOLEAN reset_vec=FALSE;
+
+  /* we shall reduce bucket=bn*lm+... by p1=an*t+a1 where t=lm(p1)
+     and an,bn shall be defined further down only if lc(p1)!=1
+     we already know: an|bn and t|lm */
+  if(a1==NULL)
+  {
+    p_LmDelete(&lm, r);
+    return;
+  }
+
+  #ifdef KDEBUG
+  if (n_DivBy(pGetCoeff(lm),pGetCoeff(p1),r->cf))
+  #endif
+  {
+    number c=n_Div(pGetCoeff(lm),pGetCoeff(p1),r->cf);
+    //StringSetS("mult cf:");n_Write(c,r->cf);StringAppendS("\n");
+    //PrintS(StringEndS());
+    #ifdef KDEBUG
+    if (n_IsZero(c,r->cf))
+    {
+      StringSetS("a/b: ");n_Write(pGetCoeff(lm),r->cf);StringAppendS(" / ");
+      n_Write(pGetCoeff(p1),r->cf);StringAppendS("\n");PrintS(StringEndS());
+    }
+    #endif
+    p_SetCoeff(lm,c,r);
+  }
+  #ifdef KDEBUG
+  else
+  {
+    PrintS("bug\n");
+  }
+  #endif
+  if (p_GetComp(p1, r) != p_GetComp(lm, r))
+  {
+    p_SetCompP(a1, p_GetComp(lm, r), r);
+    reset_vec = TRUE;
+    p_SetComp(lm, p_GetComp(p1, r), r);
+    p_Setm(lm, r);
+  }
+
+  p_ExpVectorSub(lm, p1, r);
+  l1--;
+
+  assume((unsigned)l1==pLength(a1));
+
+#ifdef HAVE_SHIFTBBA
+  poly lmRight;
+  poly lm_org;
+  if (r->isLPring)
+  {
+    int firstBlock = p_mFirstVblock(p1, r);
+    lm_org=lm;
+    k_SplitFrame(lm, lmRight, si_max(firstBlock, 1), r);
+  }
+#endif
+
+#ifdef HAVE_SHIFTBBA
+  if (r->isLPring)
+  {
+    poly tmp=r->p_Procs->pp_Mult_mm(a1, lmRight, r);
+    kBucket_Minus_m_Mult_p(bucket, lm,tmp, &l1, spNoether);
+    p_Delete(&tmp,r);
+    p_LmDelete(&lmRight,r);
+    p_LmDelete(lm_org,r);
+  }
+  else
+#endif
+  {
+    kBucket_Minus_m_Mult_p(bucket, lm, a1, &l1, spNoether);
+  }
+
+#if 0
+  if (backuped)
+    p_SetCoeff0(a1,coef,r);
+#endif
+
+  p_LmDelete(&lm, r);
+  if (reset_vec) p_SetCompP(a1, 0, r);
+  kbTest(bucket);
+  return;
+}
+
 #ifndef USE_COEF_BUCKETS
 void kBucketSimpleContent(kBucket_pt bucket)
 {
@@ -1435,19 +1508,26 @@ int ksCheckCoeff(number *a, number *b, const coeffs r)
   n_Test(an,r);
   n_Test(bn,r);
 
-  number cn = n_SubringGcd(an, bn, r);
-
-  if(n_IsOne(cn, r))
+  if (UNLIKELY(nCoeff_is_Ring(r) && n_DivBy(bn,an,r))) // in NF
   {
-    an = n_Copy(an, r);
-    bn = n_Copy(bn, r);
+      bn = n_ExactDiv(bn, an, r);
+      an = n_Init(1, r);
   }
   else
   {
-    an = n_ExactDiv(an, cn, r);
-    bn = n_ExactDiv(bn, cn, r);
+    number cn = n_SubringGcd(an, bn, r);
+    if(n_IsOne(cn, r))
+    {
+      an = n_Copy(an, r); // a/1
+      bn = n_Copy(bn, r); // b/1
+    }
+    else
+    {
+      an = n_ExactDiv(an, cn, r);
+      bn = n_ExactDiv(bn, cn, r);
+    }
+    n_Delete(&cn, r);
   }
-  n_Delete(&cn, r);
   if (n_IsOne(an, r))
   {
     c = 1;
