@@ -36,13 +36,6 @@ static poly mp_SelectId (ideal I, poly what, const ring R);
 /// create a r x c zero-matrix
 matrix mpNew(int r, int c)
 {
-  int rr=r;
-  if (rr<=0) rr=1;
-  //if ( (((int)(MAX_INT_VAL/sizeof(poly))) / rr) <= c)
-  //{
-  //  Werror("internal error: creating matrix[%d][%d]",r,c);
-  //  return NULL;
-  //}
   matrix rc = (matrix)omAllocBin(sip_sideal_bin);
   rc->nrows = r;
   rc->ncols = c;
@@ -132,7 +125,7 @@ matrix mp_InitI(int r, int c, int v, const ring R)
 }
 
 /// c = f*a
-matrix mp_MultI(matrix a, int f, const ring R)
+matrix mp_MultI(matrix a, long f, const ring R)
 {
   int k, n = a->nrows, m = a->ncols;
   poly p = p_ISet(f, R);
