@@ -76,10 +76,11 @@ typedef enum rRingOrder_t
   ringorder_s, ///< s?
   ringorder_lp,
   ringorder_dp,
-  ringorder_rp,
+  ringorder_ip,
   ringorder_Dp,
   ringorder_wp,
   ringorder_Wp,
+  ringorder_Ip, /// degree, ip
   ringorder_ls,
   ringorder_ds,
   ringorder_Ds,
@@ -89,11 +90,15 @@ typedef enum rRingOrder_t
   ringorder_L,
   // the following are only used internally
   ringorder_aa, ///< for idElimination, like a, except pFDeg, pWeigths ignore it
-  ringorder_rs, ///< opposite of ls
+  ringorder_is, ///< opposite of ls
   ringorder_IS, ///< Induced (Schreyer) ordering
   ringorder_unspec
 } rRingOrder_t;
 
+// compat entries:
+#define ringorder_rp ringorder_ip
+#define ringorder_rs ringorder_is
+
 typedef enum rOrderType_t
 {
   rOrderType_General = 0, ///< non-simple ordering as specified by currRing
@@ -733,6 +738,8 @@ ring   rAssure_InducedSchreyerOrdering(const ring r, BOOLEAN complete = TRUE, in
 
 ring   rAssure_dp_S(const ring r);
 ring   rAssure_dp_C(const ring r);
+ring   rAssure_Dp_C(const ring r);
+ring   rAssure_Wp_C(const ring r, intvec *w);
 ring   rAssure_C_dp(const ring r);
 ring   rAssure_c_dp(const ring r);
 
@@ -764,6 +771,8 @@ inline BOOLEAN rHasMixedOrdering(const ring r) { return (r->MixedOrder); }
 // #define rHasLocalOrMixedOrdering(R) ((R)->OrdSgn==-1)
 
 BOOLEAN rOrd_is_Totaldegree_Ordering(const ring r);
+BOOLEAN rOrd_is_dp(const ring r);
+BOOLEAN rOrd_is_ds(const ring r);
 
 /// return TRUE if p_SetComp requires p_Setm
 BOOLEAN rOrd_SetCompRequiresSetm(const ring r);
