@@ -152,6 +152,26 @@ void id_Delete (ideal * h, ring r)
   *h=NULL;
 }
 
+void id_Delete0 (ideal * h, ring r)
+{
+  const long elems = IDELEMS(*h);
+
+ assume( (*h)->m != NULL );
+
+ long j = elems;
+ do
+ {
+   j--;
+   poly pp=((*h)->m[j]);
+   if (pp!=NULL) p_Delete(&pp, r);
+ }
+ while (j>0);
+
+ omFree((ADDRESS)((*h)->m));
+ omFreeBin((ADDRESS)*h, sip_sideal_bin);
+ *h=NULL;
+}
+
 
 /// Shallowdeletes an ideal/matrix
 void id_ShallowDelete (ideal *h, ring r)
@@ -217,6 +237,32 @@ void idSkipZeroes (ideal ide)
   }
 }
 
+int idSkipZeroes0 (ideal ide)
+{
+  assume (ide != NULL);
+
+  int k;
+  int j = -1;
+  int idelems=IDELEMS(ide);
+
+  k=0;
+  while((k<idelems)&&(ide->m[k] != NULL)) k++;
+  if (k==idelems) return idelems;
+  // now: k: pos of first NULL entry
+  j=k; k=k+1;
+  for (; k<idelems; k++)
+  {
+    if (ide->m[k] != NULL)
+    {
+      ide->m[j] = ide->m[k];
+      ide->m[k] = NULL;
+      j++;
+    }
+  }
+  if (j<=1) return 1;
+  return j;
+}
+
 /// copies the first k (>= 1) entries of the given ideal/module
 /// and returns these as a new ideal/module
 /// (Note that the copied entries may be zero.)
@@ -2140,3 +2186,15 @@ ideal id_Delete_Pos(const ideal I, const int p, const ring r)
   for(int i=p+1;i<IDELEMS(I);i++) ret->m[i-1]=p_Copy(I->m[i],r);
   return ret;
 }
+
+ideal id_PermIdeal(ideal I,int R, int C,const int *perm, const ring src, const ring dst,
+       nMapFunc nMap, const int *par_perm, int P, BOOLEAN use_mult)
+{
+  ideal II=(ideal)mpNew(R,C);
+  II->rank=I->rank;
+  for(int i=R*C-1; i>=0; i--)
+  {
+    II->m[i]=p_PermPoly(I->m[i],perm,src,dst,nMap,par_perm,P,use_mult);
+  }
+  return II;
+}
