@@ -59,8 +59,10 @@ ideal idInit (int size, int rank=1);
 
 /*- deletes an ideal -*/
 void id_Delete (ideal* h, ring r);
+void id_Delete0 (ideal* h, ring r);
 void id_ShallowDelete (ideal* h, ring r);
 void idSkipZeroes (ideal ide);
+int idSkipZeroes0 (ideal ide);
   /*gives an ideal the minimal possible size*/
 
 /// number of non-zero polys in F
@@ -182,4 +184,8 @@ ideal id_Delete_Pos(const ideal I, const int pos, const ring r);
 
 /// for julia: convert an array of poly to vector
 poly id_Array2Vector(poly *m, unsigned n, const ring R);
+
+/// mapping ideals/matrices to other rings
+ideal id_PermIdeal(ideal I,int R, int C,const int *perm, const ring src,
+   const ring dst, nMapFunc nMap, const int *par_perm, int P, BOOLEAN use_mult);
 #endif
