@@ -12,6 +12,8 @@
 
 
 #include "omConfig.h"
+
+#ifdef HAVE_OMALLOC
 #include "omDefaultConfig.h"
 #include "omMalloc.h"
 #include "omalloc.h"
@@ -28,12 +30,20 @@
  *
  *******************************************************************/
 /* allocation of large addr */
+
+#if defined(HAVE_MALLOC_SIZE) || defined(HAVE_MALLOC_USABLE_SIZE)
+  #include <stdlib.h>
+  #ifdef HAVE_MALLOC_H
+    #include <malloc.h>
+  #elif defined(HAVE_MALLOC_MALLOC_H)
+    #include <malloc/malloc.h>
+  #endif
+#endif
+
 #if defined(HAVE_MALLOC_SIZE)
-#include <malloc/malloc.h>
-#define _omSizeOfLargeAddr(addr) (malloc_size(addr))
+  #define _omSizeOfLargeAddr(addr) (malloc_size(addr))
 #elif defined(HAVE_MALLOC_USABLE_SIZE)
-#include <stdlib.h>
-#define _omSizeOfLargeAddr(addr) (malloc_usable_size(addr))
+  #define _omSizeOfLargeAddr(addr) (malloc_usable_size(addr))
 #else
 void* omAllocLarge(size_t size)
 {
@@ -363,4 +373,5 @@ void omVfreeToSystem(void* page, size_t size)
   OM_VFREE_HOOK(size);
 }
 
+#endif /*HAVE_OMALLOC*/
 #endif /* OM_ALLOC_SYSTEM_C */
